import matplotlib.pyplot as plt
import matplotlib.ticker as ticker

def iter_disp(gen_cnt,best_mod_fit,best_stdev_fit,best_feat_fit):

    print("Iteration -",gen_cnt+1,"complete","......",\
                  "best_score: {:.4f}, score_stdev: {:.4f}, feat_fitness: {:.4f}".\
                  format(best_mod_fit[-1], best_stdev_fit[-1], best_feat_fit[-1]))

def sol_disp(sol):
    print(sol)


def graph_disp(self,metric):
    fig, ax = plt.subplots()
    plt.plot(self.monitor[metric])
    plt.title(str(metric) + str(" vs Iterations"))
    plt.xlabel("Iterations")
    plt.ylabel(metric)
    ax.set_xlim(xmin=0)
    tick_space = round(len(self.monitor[metric]) / 15)
    ax.xaxis.set_major_locator(ticker.MultipleLocator(tick_space))
    plt.xticks(rotation=45)
    plt.show()
    return


from setuptools import setup
from distutils.extension import Extension

ext_modules = [ ]

ext_modules += [
    Extension("tracta_ml.evolve", [ "tracta_ml/cython/evolve.c" ]),
    Extension("tracta_ml.genetic_operators", ["tracta_ml/cython/genetic_operators.c"]),
    Extension("tracta_ml.model_optimizer", ["tracta_ml/cython/model_optimizer.c"]),
    Extension("tracta_ml.pool_maintenance", ["tracta_ml/cython/pool_maintenance.c"]),
]

setup(name='tracta_ml',
      version='1.2.4',
      description='Combined hyper-parameter optimization and feature selection\
      for machine learning models using micro genetic algorithms',
      classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python :: 3.5',
      ],
      url='https://github.com/SankethNagarajan/tracta_ml',
      author='Sanketh Nagarajan',
      author_email='sanketh.objml@gmail.com',
      license='BSD 3-Clause "New" or "Revised" License',
      packages=['tracta_ml'],
      ext_modules=ext_modules,
      install_requires=['sklearn', 'numpy', 'pandas',\
                        'datetime','matplotlib',
                        ],
      zip_safe=False)